{% load staticfiles %}
{% comment %}
    Root file to be used in any theme. Contains all necessary (and up-to-date) libraries.
{% endcomment %}
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>{% block title %}{% endblock %}</title>

    {% block core_css %}
        <link rel="stylesheet" href="{% static 'core_main_app/libs/bootstrap/3.3.7/css/bootstrap.css' %}" />
        <link rel="stylesheet" href="{% static 'core_main_app/libs/font-awesome/4.7.0/css/font-awesome.css' %}" />
        <link rel="stylesheet" href="{% static 'core_main_app/libs/jquery-ui/1.12.1/jquery-ui.css' %}" />
        <link rel="stylesheet" href="{% static 'core_main_app/libs/jquery-ui/1.12.1/jquery-ui.structure.css' %}" />
        <link rel="stylesheet" href="{% static 'core_main_app/libs/jquery-ui/1.12.1/jquery-ui.theme.css' %}" />
        <link rel="stylesheet" href="{% static 'core_main_app/libs/bootstrap/3.3.7/css/bootstrap-theme.css' %}" />
        <link rel="stylesheet" href="{% static 'core_main_app/common/css/patch.css' %}" />
    {% endblock %}
    {% block theme_css %}{% endblock %}
    {% block app_css %}{% endblock %}
</head>
<body>
    {% block body %}{% endblock %}
    {% block app_modals %}{% endblock %}

    {% block core_js %}
        <script src="{% static 'core_main_app/libs/jquery/3.1.1/jquery.js' %}"></script>
        <script src="{% static 'core_main_app/libs/jquery-ui/1.12.1/jquery-ui.js' %}"></script>
        <script src="{% static 'core_main_app/libs/bootstrap/3.3.7/js/bootstrap.js' %}"></script>
        <script src="{% static 'core_main_app/common/js/csrf.js' %}"></script>

        {% include 'core_main_app/_render/common/messages.html' %}
    {% endblock %}
    {% block theme_js %}{% endblock %}
    {% block app_js %}{% endblock %}
</body>
</html>