{% extends 'core_main_app/_render/admin/theme/tools/modal.html' %}

{% block modal_id %}edit-object-modal{% endblock %}
{% block modal_title %}Edit {{ data.object_name }}{% endblock %}

{% block modal_body %}
{% endblock %}

{% block modal_footer %}
<a class="btn btn-default pull-left" data-dismiss="modal" href="#"><i class="fa fa-times"></i> Close</a>
<a id="edit-object-save" class="btn btn-primary" href="#"><i class="fa fa-save"></i> Save</a>
{% endblock %}