<select class='dependency'>
    <option value="None">-------------</option>
    {% for template in templates %}
        <option value='{{template.current}}'>{{template.title}}</option>
    {% endfor %}
</select>