""" Rights for core main app
"""

# Anonymous group
anonymous_group = "anonymous"

# Default group
default_group = "default"

# API rights
api_content_type = "api"
api_access = "api_access"

# Data
edit_data = "edit_data"
delete_data = "delete_data"

# Form
edit_form = "edit_form"
delete_form = "delete_form"

# Workspace
CAN_READ_CODENAME = "can_read_workspace_"
CAN_WRITE_CODENAME = "can_write_workspace_"

CAN_READ_NAME = "Can read workspace "
CAN_WRITE_NAME = "Can write workspace "

CONTENT_TYPE_APP_LABEL = "core_main_app"

