{% extends 'core_main_app/_render/admin/theme/tools/modal.html' %}

{% block modal_id %}remove-rights-modal{% endblock %}
{% block modal_title %}Remove user's rights from workspace{% endblock %}


{% block modal_body %}
<div class="alert alert-danger" id="remove_rights_banner_errors" style="display: none;">
        <a href="#" class="close" data-hide="alert" aria-label="close">&times;</a>
     	<h4><i class="fa fa-exclamation-circle"></i> Error</h4>
        <div id="remove_rights_errors"></div>
</div>
<input type="hidden" class="remove-rights-id"/>
<input type="hidden" class="remove-rights-group-or-user"/>
<p>Are you sure you want to remove access to the workspace from this {{group}} ?</p>
{% endblock %}

{% block modal_footer %}
<a class="btn btn-default pull-left" data-dismiss="modal" href="#"><i class="fa fa-times"></i> Cancel</a>
<a id="remove-yes" class="btn btn-default" href="#"><i class="fa fa-check"></i> Remove</a>
{% endblock %}