<div id="{% block modal_id %}{% endblock %}" class="modal fade modal-default">
    <div class="modal-dialog {% block modal_class %}{% endblock %}">
        <div class="modal-content">
            <div class="modal-header">
                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
                <h4 class="modal-title">{% block modal_title %}{% endblock %}</h4>
            </div>
            <div class="modal-body">{% block modal_body %}{% endblock %}</div>
            <div class="modal-footer">
                {% block modal_footer %}{% endblock %}
            </div>
        </div>
    </div>
</div>